<?php

namespace Drupal\dynamic_path_aliases;

/**
 * Provides interface for dynamic path aliases manager.
 */
interface DynamicPathsManagerInterface {

  /**
   * Match path with definition.
   *
   * @param string $path
   *   The path.
   * @param string $source
   *   The definition source path property.
   * @param string $return
   *   The definition return path property.
   *
   * @return string
   *   Returns the matched path.
   */
  public function match(string $path, string $source, string $return): ?string;

  /**
   * Get path by alias.
   *
   * @param string $path
   *   The path.
   *
   * @return string
   *   Returns the path.
   */
  public function getPathByAlias(string $path): ?string;

  /**
   * Get alias by path.
   *
   * @param string $path
   *   The path.
   *
   * @return string
   *   Returns the alias.
   */
  public function getAliasByPath(string $path): ?string;

  /**
   * Get path match cache.
   *
   * @param string $key
   *   The cache key.
   *
   * @return string|null
   *   Returns the cached match value.
   */
  public function getCache(string $key): ?string;

  /**
   * Set path match cache.
   *
   * @param string $key
   *   The cache key.
   * @param string $value
   *   The value to cache.
   * @param array $tags
   *   The cache tags.
   */
  public function setCache(string $key, string $value, array $tags = []): void;

}
