<?php

namespace Drupal\dynamic_path_aliases\Form;

use Drupal\Core\Extension\ExtensionPathResolver;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides dynamic paths settings form.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * The dynamic path aliases settings name.
   */
  const SETTINGS = 'dynamic_path_aliases.settings';

  /**
   * The extension path resolver.
   *
   * @var \Drupal\Core\Extension\ExtensionPathResolver
   */
  protected ExtensionPathResolver $extensionPathResolver;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->extensionPathResolver = $container->get('extension.path.resolver');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'dynamic_path_aliases_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return [static::SETTINGS];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config(static::SETTINGS);
    $form['aliases'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Path aliases (YAML)'),
      '#description' => $this->t('Define dynamic path aliases in YAML format.'),
      '#default_value' => $config->get('aliases'),
      '#attributes' => ['data-yaml-editor' => 'true'],
    ];
    $form['help'] = [
      '#type' => 'details',
      '#title' => $this->t('Help'),
    ];
    $form['help']['example'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Example: Path aliases (YAML)'),
      '#description' => $this->t('Set dynamic path aliases on user and article content routes.'),
      '#disabled' => TRUE,
      '#default_value' => file_get_contents($this->extensionPathResolver->getPath('module', 'dynamic_path_aliases') . '/config/schema/example.yml'),
      '#attributes' => ['data-yaml-editor' => 'true'],
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->configFactory->getEditable(static::SETTINGS);
    $config->set('aliases', $form_state->getValue('aliases'));
    $config->save();
    drupal_flush_all_caches();
    parent::submitForm($form, $form_state);
  }

}
