<?php

namespace Drupal\dynamic_path_aliases\PathProcessor;

use Drupal\Core\PathProcessor\InboundPathProcessorInterface;
use Drupal\Core\PathProcessor\OutboundPathProcessorInterface;
use Drupal\Core\Render\BubbleableMetadata;
use Drupal\dynamic_path_aliases\DynamicPathsManagerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Provides dynamic path aliases inbound and outbound processor.
 */
class DynamicPathProcessor implements InboundPathProcessorInterface, OutboundPathProcessorInterface {

  /**
   * The dynamic path aliases manager.
   *
   * @var \Drupal\dynamic_path_aliases\DynamicPathsManagerInterface
   */
  protected DynamicPathsManagerInterface $dynamicPathsManager;

  /**
   * DynamicPathProcessor constructor.
   *
   * @param \Drupal\dynamic_path_aliases\DynamicPathsManagerInterface $dynamicPathsManager
   *   The dynamic path aliases manager.
   */
  public function __construct(DynamicPathsManagerInterface $dynamicPathsManager) {
    $this->dynamicPathsManager = $dynamicPathsManager;
  }

  /**
   * {@inheritdoc}
   */
  public function processInbound($path, Request $request): string {
    if ($sourcePath = $this->dynamicPathsManager->getPathByAlias($path)) {
      return $sourcePath;
    }
    return $path;
  }

  /**
   * {@inheritdoc}
   */
  public function processOutbound($path, &$options = [], Request $request = NULL, BubbleableMetadata $bubbleable_metadata = NULL): string {
    if ($alias = $this->dynamicPathsManager->getAliasByPath($path)) {
      return $alias;
    }
    return $path;
  }

}
